@@ -18,7 +18,6 @@ from trailblazer.io.controller import ReadFile
 from trailblazer.models import Config
 from trailblazer.server.wiring import setup_dependency_injection
 from trailblazer.services.analysis_service.analysis_service import AnalysisService
-from trailblazer.services.job_service import JobService
 from trailblazer.store.database import get_session, initialize_database
 from trailblazer.store.models import Analysis, User
 from trailblazer.store.store import Store
@@ -96,36 +95,36 @@ def init(context, reset, force):
 
 @base.command()
 @inject
-def scan(
-    job_service: JobService = Provide[Container.job_service],
-    analysis_service: AnalysisService = Provide[Container.analysis_service],
-):
+def scan(analysis_service: AnalysisService = Provide[Container.analysis_service]):
     """Scan ongoing analyses in SLURM"""
     analysis_service.update_ongoing_analyses()
-    job_service.update_upload_jobs()
+    analysis_service.update_uploading_analyses()
     LOG.info("All analyses updated!")
 
 
 @base.command("update-analysis")
+@inject
 @click.argument("analysis_id")
-@click.pass_context
-def update_analysis(context, analysis_id: int):
+def update_analysis(
+    analysis_id: int,
+    analysis_service: AnalysisService = Provide[Container.analysis_service],
+):
     """Update status of a single analysis."""
-    trailblazer_db: Store = context.obj["trailblazer_db"]
-    trailblazer_db.update_run_status(analysis_id=analysis_id)
+    analysis_service.update_analysis_meta_data(analysis_id)
 
 
 @base.command("add-user")
 @click.option("--name", help="Name of new user to add")
+@click.option("--abbreviation", help="Abbreviation of new user to add")
 @click.argument("email", default=environ_email())
 @click.pass_context
-def add_user_to_db(context, email: str, name: str) -> None:
+def add_user(context, email: str, name: str, abbreviation: str) -> None:
     """Add a new user to the database."""
     trailblazer_db: Store = context.obj["trailblazer_db"]
     existing_user = trailblazer_db.get_user(email=email, exclude_archived=False)
     if is_existing_user(user=existing_user, email=email):
         return
-    new_user = trailblazer_db.add_user(email=email, name=name)
+    new_user = trailblazer_db.add_user(email=email, name=name, abbreviation=abbreviation)
     LOG.info(f"New user added: {new_user.email} ({new_user.id})")
 
 
@@ -192,13 +191,15 @@ def unarchive_user(context, email: str) -> None:
 
 
 @base.command()
+@inject
 @click.argument("analysis_id", type=int)
-@click.pass_context
-def cancel(context, analysis_id):
+def cancel(
+    analysis_id: int,
+    analysis_service: AnalysisService = Provide[Container.analysis_service],
+):
     """Cancel all jobs in an analysis."""
-    trailblazer_db: Store = context.obj["trailblazer_db"]
     try:
-        trailblazer_db.cancel_ongoing_analysis(analysis_id=analysis_id, email=environ_email())
+        analysis_service.cancel_analysis(analysis_id)
     except Exception as error:
         LOG.error(error)
 
@@ -232,7 +233,7 @@ def set_analysis_status(
     """Set the status of the latest analysis for a given case id."""
     trailblazer_db: Store = context.obj["trailblazer_db"]
     try:
-        trailblazer_db.update_analysis_status(case_id=case_id, status=status)
+        trailblazer_db.update_analysis_status_by_case_id(case_id=case_id, status=status)
     except ValueError as error:
         LOG.error(error)
         raise click.Abort from error
