@@ -1,9 +1,13 @@
 from pydantic import BaseModel
 
-from trailblazer.clients.slurm_api_client.dto.common import SlurmError, SlurmJobInfo, SlurmWarning
+from trailblazer.clients.slurm_api_client.dto.common import (
+    SlurmError,
+    SlurmAPIJobInfo,
+    SlurmWarning,
+)
 
 
 class SlurmJobsResponse(BaseModel):
-    jobs: list[SlurmJobInfo]
+    jobs: list[SlurmAPIJobInfo]
     errors: list[SlurmError] | None = None
     warnings: list[SlurmWarning] | None = None
