@@ -41,6 +41,8 @@ class Workflow(StrEnum):
     MIP_DNA: str = "MIP-DNA"
     MIP_RNA: str = "MIP-RNA"
     MUTANT: str = "MUTANT"
+    RSYNC: str = "RSYNC"
+    FASTQ: str = "FASTQ"
 
 
 class SlurmSqueueHeader(StrEnum):
@@ -73,6 +75,10 @@ class SlurmJobStatus(StrEnum):
     def ongoing_statuses(cls) -> tuple:
         return cls.PENDING, cls.RUNNING, cls.COMPLETING
 
+    @classmethod
+    def fail_statuses(cls) -> tuple:
+        return cls.FAILED, cls.TIME_OUT
+
 
 class CharacterFormat(StrEnum):
     """Define character encoding/decoding to use."""
