@@ -1,4 +1,4 @@
-from datetime import datetime
+from datetime import date, datetime
 
 from pydantic import BaseModel
 
@@ -11,6 +11,7 @@ class User(BaseModel):
     id: int
     is_archived: bool | None = False
     name: str | None = None
+    abbreviation: str | None = None
 
 
 class Job(BaseModel):
@@ -27,24 +28,28 @@ class Job(BaseModel):
 class AnalysisResponse(BaseModel):
     id: int
     case_id: str
-    version: str | None = None
-    logged_at: datetime | None = None
-    started_at: datetime | None = None
-    completed_at: datetime | None = None
-    status: TrailblazerStatus
-    priority: str
-    out_dir: str | None = None
-    config_path: str | None = None
     comment: str | None = None
+    completed_at: datetime | None = None
+    config_path: str | None = None
+    delivered_by: str | None = None
+    delivered_date: date | None = None
     is_visible: bool = True
-    type: str | None = None
-    user_id: int | None = None
-    progress: float
-    workflow: str | None = None
-    ticket_id: str | None = None
-    uploaded_at: datetime | None = None
-    workflow_manager: WorkflowManager
-    user: User | None = None
-    latest_failed_job: Job | None = None
+    is_delivered: bool
     jobs: list[Job] = []
+    latest_failed_job: Job | None = None
+    logged_at: datetime | None = None
+    order_id: int | None = None
+    out_dir: str | None = None
+    priority: str
+    progress: float
+    started_at: datetime | None = None
+    status: TrailblazerStatus
+    ticket_id: str | None = None
+    type: str | None = None
     upload_jobs: list[Job] = []
+    uploaded_at: datetime | None = None
+    user_id: int | None = None
+    user: User | None = None
+    version: str | None = None
+    workflow: str | None = None
+    workflow_manager: WorkflowManager
