@@ -1,4 +1,5 @@
 import datetime
+import uuid
 
 from sqlalchemy import Column, ForeignKey, UniqueConstraint, orm, types
 
@@ -40,6 +41,8 @@ class User(Model):
     id = Column(types.Integer, primary_key=True)
     is_archived = Column(types.Boolean, default=False)
     name = Column(types.String(128))
+    abbreviation = Column(types.String(32), unique=True, nullable=False)
+    refresh_token = Column(types.Text)
 
     runs = orm.relationship("Analysis", backref="user")
 
@@ -89,8 +92,10 @@ class Analysis(Model):
     version = Column(types.String(32))
     workflow = Column(types.String(32))
     workflow_manager = Column(types.Enum(*WorkflowManager.list()), default=WorkflowManager.SLURM)
+    tower_workflow_id = Column(types.String(32), nullable=True, default=None)
 
     jobs = orm.relationship("Job", cascade="all,delete", backref="analysis")
+    delivery = orm.relationship("Delivery", uselist=False)
 
     @property
     def has_ongoing_status(self) -> bool:
@@ -107,11 +112,22 @@ class Analysis(Model):
         """Return upload jobs."""
         return [job for job in self.jobs if job.job_type == JobType.UPLOAD]
 
+    @property
+    def delivered_by(self) -> str | None:
+        return self.delivery.user.abbreviation if self.delivery else None
+
+    @property
+    def delivered_date(self) -> datetime.datetime | None:
+        return self.delivery.delivered_date if self.delivery else None
+
     def to_dict(self) -> dict:
         """Return a dictionary representation of the object."""
         return {
             "id": self.id,
             "case_id": self.case_id,
+            "is_delivered": bool(self.delivery),
+            "delivered_by": self.delivered_by,
+            "delivered_date": self.delivered_date,
             "version": self.version,
             "logged_at": self.logged_at,
             "started_at": self.started_at,
@@ -133,6 +149,21 @@ class Analysis(Model):
         }
 
 
+class Delivery(Model):
+    """Tracks when and by whom an analysis was delivered."""
+
+    __tablename__ = "delivery"
+    __table_args__ = (UniqueConstraint("analysis_id"),)
+
+    id = Column(types.Uuid, primary_key=True, default=uuid.uuid4)
+    analysis_id = Column(ForeignKey(Analysis.id, ondelete="CASCADE"), nullable=False)
+    delivered_by = Column(ForeignKey(User.id), nullable=False)
+    delivered_date = Column(types.Date, nullable=False)
+
+    analysis = orm.relationship("Analysis", foreign_keys=[analysis_id], back_populates="delivery")
+    user = orm.relationship("User", foreign_keys=[delivered_by])
+
+
 class Job(Model):
     """Represent a step in the workflow."""
 
